@@ -13,8 +13,7 @@ use lib "$FindBin::Bin/../lib";
 
 use Protocol::DBus::Client;
 
-#my $dbus = Protocol::DBus::Client::system();
-my $dbus = Protocol::DBus::Client::login_session();
+my $dbus = $> ? Protocol::DBus::Client::login_session() : Protocol::DBus::Client::system();
 
 $SIG{'PIPE'} = 'IGNORE';
 
@@ -30,8 +29,8 @@ my $fileno = $dbus->fileno();
 # the following is quick and easy:
 vec( my $mask, $fileno, 1 ) = 1;
 
-while (!$dbus->do_authn()) {
-    if ($dbus->authn_pending_send()) {
+while (!$dbus->initialize()) {
+    if ($dbus->init_pending_send()) {
         select( undef, my $wout = $mask, undef, undef );
     }
     else {
@@ -39,7 +38,7 @@ while (!$dbus->do_authn()) {
     }
 }
 
-print "done authn\n";
+printf "done authn; unique bus name: %s\n", $dbus->get_unique_bus_name();
 
 #----------------------------------------------------------------------
 
@@ -52,12 +51,11 @@ $dbus->send_call(
     signature => 's',
     member => 'GetAll',
     body => ['org.freedesktop.DBus'],
-    on_return => sub {
-        $got_response = 1;
-        print "got getall response\n";
-        print Dumper shift;
-    },
-);
+)->then( sub {
+    $got_response = 1;
+    print "got getall response\n";
+    print Dumper shift;
+} );
 
 while (!$got_response) {
     my $win = $dbus->pending_send() || q<>;
